@@ -908,7 +908,7 @@ class FlickerDataFrame(object):
             raise TypeError(msg.format(str(type(mapper_or_list))))
         return self.__class__(out)
 
-    def value_counts(self, name, normalize=False, sort=True, ascending=False,
+    def value_counts(self, names, normalize=False, sort=True, ascending=False,
                      drop_null=False, nrows=None):
         """
         Returns a FlickerDataFrame that contains a frequency table of the
@@ -916,8 +916,8 @@ class FlickerDataFrame(object):
 
         Parameters
         ----------
-        name: str
-            Name of a column in the dataframe
+        names: str or list of str
+            Name of a column in the dataframe or a list of column names
         normalize: bool
             If True, the frequency counts are normalized by the number of
             rows in the entire dataframe (even when nrows is set to a non-None
@@ -982,9 +982,13 @@ class FlickerDataFrame(object):
         1   pandas      1
         2  flicker      1
         """
-        if name not in self._df.columns:
-            msg = 'column "{}" not found'
-            raise KeyError(msg.format(name))
+        if isinstance(names, six.string_types):
+            names = [names]
+        for name in names:
+            # FIXME: check that name is of type str here as well
+            if name not in self._df.columns:
+                msg = 'column "{}" not found'
+                raise KeyError(msg.format(name))
         if 'count' in self._df.columns:
             msg = ('column "count" already exists in dataframe; '
                    'please rename it before calling value_counts()')
@@ -992,13 +996,13 @@ class FlickerDataFrame(object):
 
         out = self._df
         if drop_null:
-            out = out[out[name].isNotNull()]
+            out = out[out[names].isNotNull()]
         if nrows is not None:
             out = out.limit(nrows)
 
         # .count() is lazy when called on  pyspark.sql.group.GroupedData
         # creates a column called "count"
-        out = out.groupBy(name).count()
+        out = out.groupBy(names).count()
         if sort:
             out = out.orderBy('count', ascending=ascending)
         if normalize:
@@ -1010,11 +1014,15 @@ class FlickerDataFrame(object):
         return self.__class__(out)
 
     def count_value(self, name, value):
+        """ Count the number of times a value appears in a column.
+            CAVEAT: spark ignores data types when doing this. See
+            https://www.perfectlyrandom.org/bites/2020/03/19/spark-ignores-data-types-when-filtering-on-equality
+            for more details. This is an issue with spark (and even SQL) not
+            with flicker.
+        """
         if name not in self._df.columns:
             msg = 'column "{}" not found'
             raise KeyError(msg.format(name))
-        # FIXME: the dtype is not respected here value = '1' or 1 returns the
-        #  same Column object when name points to a sting-type column.
         return self._df[self._df[name].isin([value])].count()
 
     def sort_values(self, by=None, ascending=True):
@@ -1397,7 +1405,7 @@ class FlickerDataFrame(object):
                 raise KeyError(msg)
         return self.__class__(self._df.drop(*names))
 
-    def join(self, other, how='inner', on=None,
+    def join(self, other, on=None, how='inner',
              lsuffix=None, rsuffix=None, lprefix=None, rprefix=None):
         # Note that any None column value is not matched on. It's ignored.
 
@@ -1446,7 +1454,7 @@ class FlickerDataFrame(object):
             on = [on]
 
         # Convert list into a dict for streamlined handling
-        if isinstance(on, Iterable):
+        if isinstance(on, (list, tuple)):
             on = {name: name for name in on}
 
         # Since we allow renaming of columns, we need to rename the keys in
@@ -1502,7 +1510,7 @@ class FlickerDataFrame(object):
         # Join the (possibly) renamed columns
         out = left._df.join(other=right._df, on=on, how=how)
         if len(set(out.columns)) != len(out.columns):
-            msg = ('joined dataframee contains duplicated column names '
+            msg = ('joined dataframe contains duplicated column names '
                    'which is not supported. Did you forget to provide '
                    'lprefix, rprefix, lsuffix, or rsuffix?')
             raise ValueError(msg)
